# damip

Python SDK for Digitopia Advanced Mechanical Intelligence Platform(damip).

### Installation

We use PyPI to distribute our software.

```sh
$ pip install damip
```


### Usage

```python
Python 3.8.10 (default, Nov 22 2023, 10:22:35) 
[GCC 9.4.0] on linux
Type "help", "copyright", "credits" or "license" for more information.
>>>
>>> from damip import oldtimes
>>> mybot = oldtimes.robot("Joy")
>>> mybot.hello()
'hello, I am an oldtimes robot, My name is Joy.'
>>>
```
